Description Usage Arguments Details Value Examples
Evaluate x^(a/b) and |x|^(a/b) with integer a and b with extension to conventional operations (listed under details) that would otherwise result in NaN.
1 |
x |
A number or a vector of numbers. |
a |
An integer. |
b |
An integer. |
abs |
TRUE or FALSE. |
Replace x by abs(x) below if abs == TRUE.
If a == 0 && b == 0, returns log(x).
If a != 0 && b == 0, returns exp(a*x).
Otherwise, for b != 0, evaluates x^(a/b) with the following extensions.
0^0 evaluates to 1.
If x < 0, returns (-1)^a * |x|^(a/b) if b is odd, or NaN otherwise.
If x == 0 && a < 0, returns NaN.
A vector of numbers of the same size as x. See details.
1 2 3 4 5 6 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.