Description Usage Arguments Details Value Examples
Random generator of matrices with given eigenvalues.
1 |
p |
A positive integer >= 2, the dimension. |
ev |
A vector of length |
seed |
A number, the seed for the generator. Ignored if |
The function randomly fills a p by p matrix with independent Normal(0,1) entries, takes the Q matrix from its QR decomposition, and returns Q' diag(ev) Q.
A p by p matrix whose eigenvalues equal to ev.
1 2 3 4 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.